@@ -1,12 +1,18 @@
 import base64
 import hashlib
+import logging
 import math
 import time
 
+from django.conf import settings
 from ebaysuds import EbaySuds, WSDL_URL, ebaysuds_config
 from suds.plugin import PluginContainer
 
 
+logging.basicConfig()
+log = logging.getLogger(__name__)
+
+
 class UnrecognisedPayloadTypeError(Exception):
     pass
 
@@ -45,34 +51,39 @@ class NotificationHandler(object):
         ctx = plugins.message.received(reply=message)
         result = soapclient.succeeded(soapclient.method.binding.input, ctx.reply)
 
+        self._parse_header(self.client.sudsclient.last_received().getChild("soap:Envelope").getChild("soap:Header"))
+
         if self.validate(result):
             return result
 
+    def _parse_header(self, header_xml):
+        log.info(header_xml)
+
     def validate(self, message):
         """
         As per:
         http://developer.ebay.com/DevZone/XML/docs/WebHelp/wwhelp/wwhimpl/common/html/wwhelp.htm?context=eBay_XML_API&file=WorkingWithNotifications-Receiving_Platform_Notifications.html
         """
         
-        # check timestamp is within 10 minutes of current time
-        timestamp = time.mktime(message.Timestamp.timetuple())
-        diff_seconds = math.fabs(time.time() - timestamp)
-        if diff_seconds > 600:
-            raise TimestampOutOfBounds("Payload timestamp was %s seconds away from current time." % diff_seconds)
-        
-        # make hash
-        m = hashlib.md5()
-        m.update(str(timestamp))
-        m.update(ebaysuds_config.get('keys', 'dev_id'))
-        if self.client.sandbox:
-            conf_section = 'sandbox_keys'
-        else:
-            conf_section = 'production_keys'
-        # sandbox?  
-        m.update(ebaysuds_config.get(conf_section, 'app_id'))
-        m.update(ebaysuds_config.get(conf_section, 'cert_id'))
-        computed_hash = base64.standard_b64encode(m.hexdigest())
-        if computed_hash != message.RequesterCredentials.NotificationSignature:
-            raise InvalidSignature(message.RequesterCredentials.NotificationSignature)
+        if not settings.DEBUG:
+            # check timestamp is within 10 minutes of current time
+            timestamp = time.mktime(message.Timestamp.timetuple())
+            diff_seconds = math.fabs(time.time() - timestamp)
+            if diff_seconds > 600:
+                raise TimestampOutOfBounds("Payload timestamp was %s seconds away from current time." % diff_seconds)
+            
+            # make hash
+            m = hashlib.md5()
+            m.update(str(timestamp))
+            m.update(ebaysuds_config.get('keys', 'dev_id'))
+            if self.client.sandbox:
+                conf_section = 'sandbox_keys'
+            else:
+                conf_section = 'production_keys'
+            m.update(ebaysuds_config.get(conf_section, 'app_id'))
+            m.update(ebaysuds_config.get(conf_section, 'cert_id'))
+            computed_hash = base64.standard_b64encode(m.hexdigest())
+            if computed_hash != message.RequesterCredentials.NotificationSignature:
+                raise InvalidSignature(message.RequesterCredentials.NotificationSignature)
 
         return True
